==> bad_ads_blocker_v1.3.tar.gz: bad_ads_blocker/blocked.php <==
<?php /*
<style>
 include 'style.css'; 
</style>
*/ ?>
<?php
include 'functions.php';

$url='https://www.google.com/adsense/gwt-properties?pid='.$GLOBALS['pub_id'].'&authuser=0&tpid='.$GLOBALS['pub_id'].'&ov=3';

$result=curl_post($url, '', $GLOBALS['arc_tab_req_string'], $GLOBALS['myheaders']); // Requesting access tokens in meta tags
unset($url);
$gwtarray=metagwt2array($result); // Converting data to array

file_put_contents($GLOBALS['temp_folder'].'xsrftoken.txt', $gwtarray['syn_token_pb']); // Put XSRF new token

	/**
	 * Get temporary access tokens:
	**/

if(is_data_safely($_GET['start'])) {
	if(isset($_GET['start']))  	$start_pos=(int)$_GET['start'];
	else						$start_pos=0;
}


for($i=0;$i<$set['num_of_pages'];$i++) {

		$params = new stdClass();
		$params->{1}='ca-'.$GLOBALS['pub_id'];
		$params=json_encode($params);

	$result=creative_review ('getWebPropertyMetricsToken', $params);

	/**
	 * Get ads list:
	**/

	if($set['text']) $type['text']='0';
	if($set['rich_media']) $type['media']='2';
	$media_types='['.implode(',',$type).']';

		$params = new stdClass();
		$params->{1}='ca-'.$GLOBALS['pub_id'];  // Publisher Id ca-pub-...
			$params->{2}->{1}=$start_pos+$i*$set['num_of_ads_per_page'];							// Start position
			$params->{2}->{2}=$set['num_of_ads_per_page'];	// Ads qty
			$params->{2}->{3}=1;							// 0 - Shown ads; 1 - already blocked ads
			$params->{2}->{5}->{16}=$media_types;			// 0 - Text; 1 - graphics; 2 - Media; If checked all types the parameter is absent.
			if(!$set['rich_media']) $params->{2}->{5}->{17}=0;			//Disappears at turning on media type
		//$params->{3}='-6928690776790362';

		$params=json_encode($params);
		$params=str_replace('"[', '[', $params);
		$params=str_replace(']"', ']', $params);

	$result=creative_review ('searchArcApprovals', $params);

	$digikey_for_req=$result->result->{5}; // Some digits required to control requests.

	foreach($result->result->{1} as $key=>$node) {
		$ad_id[$key]=$node->{4}->{1}; // Some sequence required to control requests of each ad
		//$ad_req_urls[$key]=$node->{5}->{10}; // url we can access ad sourse code
		$ad_req_urls=$node->{5}->{10}; // url we can access ad sourse code
		$ad[$key]=get_ad($ad_req_urls);	//Indexes of returned array: fulltext, header1, header2, body, url
		unset($ad[$key]['url']);
		set_time_limit(30);		//Renew time limit for each ad download
	}

	unset($result,$ad_req_urls);

	foreach($ad as $ad_unit) {
		$ad_long[]=$ad_unit;
	}

}


foreach($ad_long as $index=>$ad) {

	$body=trim($ad['body']);
	$str_len=mb_strlen($body);

	if($str_len>47) {
		$half_len=round($str_len/2, 0, PHP_ROUND_HALF_UP);
		$body1=mb_substr($ad['body'], 0, $half_len).$nl;
		$body2=mb_substr($ad['body'], $half_len);
	} else {
		$body1=$ad['body'].$nl;
		$body2='';
	}

	$text=$ad['header1'].$nl.$ad['header2'].$nl.$body1.$body2;
	$ad_arr[]=mb_strtolower($text);
}

$prev=file($GLOBALS['settings_folder'].'bad_ads_text', FILE_IGNORE_NEW_LINES);
foreach($prev as $text) {
	$ad_arr[]=$text;
}


$ad_arr=array_unique($ad_arr);

asort($ad_arr);

$out_file='';
$out='';
foreach($ad_arr as $text) {
	$text=trim($text);
	$text=trim($text, '?,.:');
	if($text) {
		$out_file.=$text.$nl;
		$out.=$text.'<br />'.$nl;		
	}

}

file_put_contents($GLOBALS['settings_folder'].'bad_ads_text', $out_file);
echo $out;

?>

==> bad_ads_blocker_v1.4.2.tar.gz: bad_ads_blocker/blocked.php <==
<?php /*
<style>
 include 'style.css'; 
</style>
*/ ?>
<?php
include 'functions.php';

$url='https://www.google.com/adsense/gwt-properties?pid='.$GLOBALS['pub_id'].'&authuser=0&tpid='.$GLOBALS['pub_id'].'&ov=3';

$result=curl_post($url, '', $GLOBALS['arc_tab_req_string'], $GLOBALS['myheaders']); // Requesting access tokens in meta tags
unset($url);
$gwtarray=metagwt2array($result); // Converting data to array

file_put_contents($GLOBALS['temp_folder'].'xsrftoken.txt', $gwtarray['syn_token_pb']); // Put XSRF new token

	/**
	 * Get temporary access tokens:
	**/

if(isset($_GET['start'])) {
	if(is_data_safely($_GET['start'])) 
		$start_pos=(int)$_GET['start'];
}
else
	$start_pos=0;
	

for($i=0;$i<$set['num_of_pages'];$i++) {

		$params = new stdClass();
		$params->{1}='ca-'.$GLOBALS['pub_id'];
		$params=json_encode($params);

	$result=creative_review ('getWebPropertyMetricsToken', $params);

	/**
	 * Get ads list:
	**/

	if($set['text']) $type['text']='0';
	if($set['rich_media']) $type['media']='2';
	$media_types='['.implode(',',$type).']';

		$params = new stdClass();
		$params->{1}='ca-'.$GLOBALS['pub_id'];  // Publisher Id ca-pub-...
			$params->{2}->{1}=$start_pos+$i*$set['num_of_ads_per_page'];							// Start position
			$params->{2}->{2}=$set['num_of_ads_per_page'];	// Ads qty
			$params->{2}->{3}=1;							// 0 - Shown ads; 1 - already blocked ads
			$params->{2}->{5}->{16}=$media_types;			// 0 - Text; 1 - graphics; 2 - Media; If checked all types the parameter is absent.
			if(!$set['rich_media']) $params->{2}->{5}->{17}=0;			//Disappears at turning on media type
		//$params->{3}='-6928690776790362';

		$params=json_encode($params);
		$params=str_replace('"[', '[', $params);
		$params=str_replace(']"', ']', $params);

	$result=creative_review ('searchArcApprovals', $params);

	$digikey_for_req=$result->result->{5}; // Some digits required to control requests.

	foreach($result->result->{1} as $key=>$node) {
		$ad_id[$key]=$node->{4}->{1}; // Some sequence required to control requests of each ad
		//$ad_req_urls[$key]=$node->{5}->{10}; // url we can access ad sourse code
		$ad_req_urls=$node->{5}->{10}; // url we can access ad sourse code
		$ad[$key]=get_ad($ad_req_urls);	//Indexes of returned array: fulltext, header1, header2, body, url
		unset($ad[$key]['url']);
		set_time_limit(30);		//Renew time limit for each ad download
	}

	unset($result,$ad_req_urls);

	foreach($ad as $ad_unit) {
		$ad_long[]=$ad_unit;
	}

}


foreach($ad_long as $index=>$ad) {

	$body=trim($ad['body']);
	$str_len=mb_strlen($body);

	if($str_len>47) {
		$half_len=round($str_len/2, 0, PHP_ROUND_HALF_UP);
		$body1=mb_substr($ad['body'], 0, $half_len).$nl;
		$body2=mb_substr($ad['body'], $half_len);
	} else {
		$body1=$ad['body'].$nl;
		$body2='';
	}

	$text=$ad['header1'].$nl.$ad['header2'].$nl.$body1.$body2;
	$ad_arr[]=mb_strtolower($text);
}

$prev=file($GLOBALS['settings_folder'].'bad_ads_text', FILE_IGNORE_NEW_LINES);
foreach($prev as $text) {
	$ad_arr[]=$text;
}


$ad_arr=array_unique($ad_arr);

asort($ad_arr);

$out_file='';
$out='';
foreach($ad_arr as $text) {
	$text=trim($text);
	$text=trim($text, '?,.:');
	if($text) {
		$out_file.=$text.$nl;
		$out.=$text.'<br />'.$nl;		
	}

}

file_put_contents($GLOBALS['settings_folder'].'bad_ads_text', $out_file);
echo $out;

?>
